# discord.js-commands-handler
## About 
A package to Sync your bot's Commands and manage interactions

- Quickly registers new Commands
- Auto deletes deleted Commands
- Managing Interactions

## Instaling discord.js-commands-handler

```sh-session
npm i discord.js-commands-handler
```

## Add Command
- Create a javascript file in the your commands folder
- Fill in `name`, `description [Only chatInput]` and `execute [function]` as forced in
```js
export default {
	name: "test",
	description: "Test Command",
	execute(client, interaction, options) {
		interaction.reply("Test successful")
	}
}
```
- Optionally, [`type [default: 1]`](https://discord-api-types.dev/api/discord-api-types-v10/enum/ApplicationCommandType), [`permission`](https://discord-api-types.dev/api/discord-api-types-payloads/common#PermissionFlagsBits) and [`options`](https://discord.js.org/#/docs/discord.js/main/typedef/ApplicationCommandOptionData)
```js
export default {
	type: 1,
	name: "test",
	description: "Test Command",
	options: [
		{
			type: 3,
			name: "test_option",
			description: "Test",
		}
	],
	permissions: [
		"BanMembers",
		"KickMembers"
	],
	execute(client, interaction, options) {
		interaction.reply("Test successful").then(() => {
			interaction.followUp(`option: ${options.getString("test_option")}`)
		})
	}
}
```

## Handling Components
- First, let's create a sample component.
- To handle interactions, prefix the `customId` property with the name of the command as in the example.
```js
const component = {
	type: 1,
	components: [
		{
			type: 2,
			customId: "ping.button",
			label: "Pong!",
			style: 1
		}
	]
}
```

- Then create a function called `componentInteraction` inside the command file and send `client`, `interaction` and `customId` arguments from the function.
- Enter the codes you want to run when the component inside the function is triggered
```js
export default {
	name: 'ping',
	description: 'Replies with Pong',
	execute(client, interaction, options) {
		const component = {
			type: 1, // ActionRow
			components: [
				{
					type: 2, // Button
					customId: "ping.button",
					label: "Pong!",
					style: 1
				}
			]
		}
		
		interaction.reply({ components: [component] })
	},
	componentInteraction(client, interaction, customId) {
		interaction.reply("Component triggered!")
	}
}
```
- If you have more than one component, you can check it `customId` (Do not write the command name where it starts).
```js
export default {
	name: 'ping',
	description: 'Replies with Pong',
	execute(client, interaction, options) {
		const component = {
			type: 1, // ActionRow
			components: [
				{
					type: 2, // Button
					customId: "ping.button",
					label: "Pong!",
					style: 1
				}
			]
		}
		
		interaction.reply({ components: [component] })
	},
	componentInteraction(client, interaction, customId) {
		if (customId == "button") {
			interaction.reply("Component triggered!")
		}
	}
}
```
## Handling Autocomplete
- First, let's create a sample autocomplete.
```js
export default {
	name: 'ping',
	description: 'Replies with Pong',
	options: [
		{
			name: "test",
			description: "Test autocomplate option",
			type: 3,
			autocomplete: true,
			required: true
		}
	],
	execute(client, interaction, options) {
		interaction.reply("Pong!")
	}
}
```
- Then create a function called `autocompleteInteraction` inside the command file and send `client`, `interaction` and `focused` arguments from the function.
```js
export default {
	name: 'ping',
	description: 'Replies with Pong',
	options: [
		{
			name: "test",
			description: "Test autocomplate option",
			type: 3,
			autocomplete: true,
			required: true
		}
	],
	execute(client, interaction, options) {
		interaction.reply("Pong!")
	},
	autocompleteInteraction(client, interaction, focused) {
		interaction.respond(
			[
				{
					name: "test",
					value: "test"
				}
			]
		)
	}
}
```
- Each time autocomplete is called the function will run and the focused value will be returned.
```js
export default {
	name: 'ping',
	description: 'Replies with Pong',
	options: [
		{
			name: "test",
			description: "Test autocomplate option",
			type: 3,
			autocomplete: true,
			required: true
		}
	],
	execute(client, interaction, options) {
		interaction.reply("Pong!")
	},
	autocompleteInteraction(client, interaction, focused) {
		console.log(focused)
	}
}
```

## Handling Modals
- First, let's create a sample modal.
- To handle interactions, prefix the `customId` property with the name of the command as in the example.
```js
export default {
	name: 'ping',
	description: 'Replies with Pong',
	execute(client, interaction, options) {
		const modal = {
			title: "Test Modal",
			customId: "ping.modal",
			components: [
				{
					type: 1,
					components: [
						{
							type: 4,
							customId: "test",
							label: "Test Modal",
							style: 1,
							placeholder: "Test"
						}
					]
				}
			]
		}
		interaction.showModal(modal)
	}
}
```
- Then create a function called `modalInteraction` inside the command file and send `client`, `interaction` and `customId` arguments from the function.
- Enter the codes you want to run when the modal inside the function is triggered
```js
export default {
	name: 'ping',
	description: 'Replies with Pong',
	execute(client, interaction, options) {
		const modal = {
			title: "Test Modal",
			customId: "ping.modal",
			components: [
				{
					type: 1,
					components: [
						{
							type: 4,
							customId: "test",
							label: "Test Modal",
							style: 1,
							placeholder: "Test"
						}
					]
				}
			]
		}
		interaction.showModal(modal)
	},
	modalInteraction(client, interaction, customId) {
		interaction.reply("Modal triggered!")
	}
}
```
- If you have more than one modal, you can check it `customId` (Do not write the command name where it starts).
```js
export default {
	name: 'ping',
	description: 'Replies with Pong',
	execute(client, interaction, options) {
		const modal = {
			title: "Test Modal",
			customId: "ping.modal",
			components: [
				{
					type: 1,
					components: [
						{
							type: 4,
							customId: "test",
							label: "Test Modal",
							style: 1,
							placeholder: "Test"
						}
					]
				}
			]
		}
		interaction.showModal(modal)
	},
	modalInteraction(client, interaction, customId) {
		if (customId == "modal") {
			interaction.reply("Modal triggered!")
		}
	}
}
```

# License
All information about the license is in the `LICENSE` file.